@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2013 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2015 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -20,7 +20,6 @@
 
 #include <string>
 #include <vector>
-#include <algorithm>
 
 using namespace std;
 
@@ -40,7 +39,7 @@ const size_t CPasswordCharPool::std_digit_len = LENGTH(std_digit_chars);
 const charT CPasswordCharPool::std_hexdigit_chars[] = _T("0123456789abcdef");
 const size_t CPasswordCharPool::std_hexdigit_len = LENGTH(std_hexdigit_chars);
 
-const charT CPasswordCharPool::std_symbol_chars[] = _T("+-=_@#$%^&;:,.<>/~\\[](){}?!|");
+const charT CPasswordCharPool::std_symbol_chars[] = _T("+-=_@#$%^&;:,.<>/~\\[](){}?!|*");
 const size_t CPasswordCharPool::std_symbol_len = LENGTH(std_symbol_chars);
 
 const charT CPasswordCharPool::easyvision_lowercase_chars[] = _T("abcdefghijkmnopqrstuvwxyz");
@@ -52,7 +51,7 @@ const size_t CPasswordCharPool::easyvision_uppercase_len = LENGTH(easyvision_upp
 const charT CPasswordCharPool::easyvision_digit_chars[] = _T("346789");
 const size_t CPasswordCharPool::easyvision_digit_len = LENGTH(easyvision_digit_chars);
 
-const charT CPasswordCharPool::easyvision_symbol_chars[] = _T("+-=_@#$%^&<>/~\\?");
+const charT CPasswordCharPool::easyvision_symbol_chars[] = _T("+-=_@#$%^&<>/~\\?*");
 const size_t CPasswordCharPool::easyvision_symbol_len = LENGTH(easyvision_symbol_chars);
 
 const charT CPasswordCharPool::easyvision_hexdigit_chars[] = _T("0123456789abcdef");
@@ -67,8 +66,10 @@ CPasswordCharPool::CPasswordCharPool(const PWPolicy &policy)
   : m_pwlen(policy.length),
     m_numlowercase(policy.lowerminlength), m_numuppercase(policy.upperminlength),
     m_numdigits(policy.digitminlength), m_numsymbols(policy.symbolminlength),
-    m_uselowercase(m_numlowercase > 0), m_useuppercase(m_numuppercase > 0),
-    m_usedigits(m_numdigits > 0), m_usesymbols(m_numsymbols > 0),
+    m_uselowercase(policy.flags & PWPolicy::UseLowercase ? true : false),
+    m_useuppercase(policy.flags & PWPolicy::UseUppercase ? true : false),
+    m_usedigits(policy.flags & PWPolicy::UseDigits ? true : false),
+    m_usesymbols(policy.flags & PWPolicy::UseSymbols ? true : false),
     m_usehexdigits(policy.flags & PWPolicy::UseHexDigits ? true : false),
     m_pronounceable(policy.flags & PWPolicy::MakePronounceable ? true : false),
     m_bDefaultSymbols(false)
@@ -78,6 +79,17 @@ CPasswordCharPool::CPasswordCharPool(const PWPolicy &policy)
          m_usedigits    || m_usesymbols   || 
          m_usehexdigits || m_pronounceable);
 
+  // Following "normalization" needed to keep MakePassword()
+  // from going into an infinite loop if we manage to become inconsistent (BR1228)
+  if (!m_uselowercase)
+    m_numlowercase = 0;
+  if (!m_useuppercase)
+    m_numuppercase = 0;
+  if (!m_usedigits)
+    m_numdigits = 0;
+  if (!m_usesymbols)
+    m_numsymbols = 0;
+
   if (policy.flags & PWPolicy::UseEasyVision) {
     m_char_arrays[LOWERCASE] = easyvision_lowercase_chars;
     m_char_arrays[UPPERCASE] = easyvision_uppercase_chars;
@@ -139,6 +151,22 @@ CPasswordCharPool::~CPasswordCharPool()
     free(const_cast<charT*>(m_char_arrays[SYMBOL]));
 }
 
+stringT CPasswordCharPool::GetDefaultSymbols()
+{
+  stringT symbols;
+  const StringX sx_symbols = PWSprefs::GetInstance()->GetPref(PWSprefs::DefaultSymbols);
+  if (!sx_symbols.empty())
+    symbols = sx_symbols.c_str();
+  else
+    symbols = std_symbol_chars;
+  return symbols;
+}
+
+void CPasswordCharPool::ResetDefaultSymbols()
+{
+  PWSprefs::GetInstance()->SetPref(PWSprefs::DefaultSymbols, std_symbol_chars);
+}
+
 CPasswordCharPool::CharType CPasswordCharPool::GetRandomCharType(unsigned int rand) const
 {
   /*
@@ -174,6 +202,18 @@ charT CPasswordCharPool::GetRandomChar(CPasswordCharPool::CharType t, unsigned i
   return retval;
 }
 
+charT CPasswordCharPool::GetRandomChar(CPasswordCharPool::CharType t) const
+{
+  PWSrand *ri = PWSrand::GetInstance();
+  uint r = ri->RangeRand(static_cast<uint>(m_lengths[t]));
+  return GetRandomChar(t, r);
+}
+
+struct RandomWrapper {
+  unsigned int operator()(unsigned int i)
+  {return PWSrand::GetInstance()->RangeRand(i);}
+};
+
 StringX CPasswordCharPool::MakePassword() const
 {
   // We don't care if the policy is inconsistent e.g. 
@@ -183,96 +223,71 @@ StringX CPasswordCharPool::MakePassword() const
   // Saves an awful amount of bother with setting values to zero and
   // back as the user changes their minds!
 
-  // Order of priority:
-  // pronouceable, hex, easyvision/normal
-
   ASSERT(m_pwlen > 0);
   ASSERT(m_uselowercase || m_useuppercase || m_usedigits ||
          m_usesymbols   || m_usehexdigits || m_pronounceable);
 
-  int lowercaseneeded, uppercaseneeded, digitsneeded, symbolsneeded;
-  int hexdigitsneeded;
 
-  StringX password = _T("");
-
-  // pronounceable passwords are handled separately:
+  // pronounceable and hex passwords are handled separately:
   if (m_pronounceable)
     return MakePronounceable();
+  if (m_usehexdigits)
+    return MakeHex();
+
+  vector<typeFreq_s> typeFreqs;
+
+  if (m_uselowercase)
+    typeFreqs.push_back(typeFreq_s(this, LOWERCASE, m_numlowercase));
+
+  if (m_useuppercase)
+    typeFreqs.push_back(typeFreq_s(this, UPPERCASE, m_numuppercase));
+
+  if (m_usedigits)
+    typeFreqs.push_back(typeFreq_s(this, DIGIT, m_numdigits));
+
+  if (m_usesymbols)
+    typeFreqs.push_back(typeFreq_s(this, SYMBOL, m_numsymbols));
+
+  // Sort requested char type in decreasing order
+  // of requested (at least) frequency:
+  sort(typeFreqs.begin(), typeFreqs.end(),
+       [](const typeFreq_s &a, const typeFreq_s &b)
+       {
+         return a.numchars > b.numchars;
+       });
 
-  bool pwRulesMet;
   StringX temp;
-
-  do {
-    charT ch;
-    CharType type;
-
-    hexdigitsneeded = (m_usehexdigits) ? m_pwlen : 0;
-    lowercaseneeded = (m_usehexdigits) ? 0 : m_numlowercase;
-    uppercaseneeded = (m_usehexdigits) ? 0 : m_numuppercase;
-    digitsneeded    = (m_usehexdigits) ? 0 : m_numdigits;
-    symbolsneeded   = (m_usehexdigits) ? 0 : m_numsymbols;
-
-    // If following assertion doesn't hold, we'll never exit the do loop!
-    ASSERT(int(m_pwlen) >= lowercaseneeded + uppercaseneeded +
-               digitsneeded + symbolsneeded + hexdigitsneeded);
-
-    temp = _T("");    // empty the password string
-
-    for (uint x = 0; x < m_pwlen; x++) {
-      unsigned int rand = PWSrand::GetInstance()->RangeRand(static_cast<unsigned int>(m_sumlengths));
-      // The only reason for passing rand as a parameter is to
-      // avoid having to generate two random numbers for each
-      // character. Alternately, we could have had a m_rand
-      // data member. Which solution is uglier is debatable.
-      type = (m_usehexdigits) ? HEXDIGIT : GetRandomCharType(rand);
-      ch = GetRandomChar(type, rand);
-      temp += ch;
-      /*
-      **  Decrement the appropriate needed character type count.
-      */
-      switch (type) {
-        case LOWERCASE:
-          lowercaseneeded--;
-          break;
-
-        case UPPERCASE:
-          uppercaseneeded--;
-          break;
-
-        case DIGIT:
-          digitsneeded--;
-          break;
-
-        case SYMBOL:
-          symbolsneeded--;
-          break;
-
-        case HEXDIGIT:
-          hexdigitsneeded--;
-          break;
-
-        default:
-          ASSERT(0); // should never happen!
-          break;
+  // First meet the 'at least' constraints
+  for (auto iter = typeFreqs.begin(); iter != typeFreqs.end(); iter++)
+    for (uint j = 0; j < iter->numchars; j++) {
+      if (!iter->vchars.empty()) {
+        temp.push_back(iter->vchars.back());
+        iter->vchars.pop_back();
+        if (temp.length() == m_pwlen)
+          goto do_shuffle; // break out of two loops, goto needed
       }
-    } // for
-
-    /*
-    * Make sure we have at least one representative of each required type
-    * after the for loop. If not, try again. Arguably, recursion would have
-    * been more elegant than a do loop, but this takes less stack...
-    */
-    pwRulesMet = (lowercaseneeded <= 0 && uppercaseneeded <= 0 &&
-                  digitsneeded <= 0 && symbolsneeded <= 0 && 
-                  hexdigitsneeded <= 0);
-
-    if (pwRulesMet) {
-      password = temp;
     }
-    // Otherwise, do not exit, do not collect $200, try again...
-  } while (!pwRulesMet);
-  ASSERT(password.length() == size_t(m_pwlen));
-  return password;
+
+
+  // Now fill in the rest
+  while (temp.length() != m_pwlen) {
+    uint i = PWSrand::GetInstance()->RangeRand(typeFreqs.size());
+    if (!typeFreqs[i].vchars.empty()) {
+      temp.push_back(typeFreqs[i].vchars.back());
+      typeFreqs[i].vchars.pop_back();
+      if (temp.length() == m_pwlen)
+        goto do_shuffle; // break out of two loops, goto needed
+    }
+  }
+
+ do_shuffle:
+  // If 'at least' values were non-zero, we have some unwanted order,
+  // se we mix things up a bit:
+  RandomWrapper rnw;
+  random_shuffle(temp.begin(), temp.end(), rnw);
+
+  ASSERT(temp.length() == size_t(m_pwlen));
+  return temp;
 }
 
 static const struct {
@@ -314,11 +329,6 @@ private:
   int m_i;
 };
 
-struct RandomWrapper {
-  unsigned int operator()(unsigned int i)
-  {return PWSrand::GetInstance()->RangeRand(i);}
-};
-
 static void leet_replace(stringT &password, unsigned int i,
                          bool usedigits, bool usesymbols)
 {
@@ -439,17 +449,45 @@ StringX CPasswordCharPool::MakePronounceable() const
   return password.c_str();
 }
 
+StringX CPasswordCharPool::MakeHex() const
+{
+  StringX password = _T("");
+  for (uint i = 0; i < m_pwlen; i++) {
+      unsigned int rand = PWSrand::GetInstance()->RangeRand(static_cast<unsigned int>(m_sumlengths));
+      charT ch = GetRandomChar(HEXDIGIT, rand);
+      password += ch;
+  }
+  return password;
+}
+
 bool CPasswordCharPool::CheckPassword(const StringX &pwd, StringX &error)
 {
+  /**
+   * A password is "Good enough" if:
+   * It is at least SufficientLength characters long
+   * OR
+   * It is at least MinLength characters long AND it has
+   * at least one uppercase and one lowercase and one (digit or other).
+   *
+   * A future enhancement of this might be to calculate the Shannon Entropy
+   * in combination with a minimum password length.
+   * http://rosettacode.org/wiki/Entropy
+   */
+
+  const size_t SufficientLength = 12;
   const size_t MinLength = 8;
-  size_t length = pwd.length();
-  // check for minimun length
+  const size_t length = pwd.length();
+
+  if (length >= SufficientLength) {
+    return true;
+  }
+
   if (length < MinLength) {
     LoadAString(error, IDSC_PASSWORDTOOSHORT);
     return false;
   }
 
-  // check for at least one  uppercase and lowercase and  digit or other
+  // check for at least one uppercase and lowercase and one (digit or other)
   bool has_uc = false, has_lc = false, has_digit = false, has_other = false;
 
   for (size_t i = 0; i < length; i++) {
