@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2011 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2015 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -55,9 +55,12 @@ enum FieldType {
   FT_XTIME_INT     = CItemData::XTIME_INT,
   FT_RUNCMD        = CItemData::RUNCMD,
   FT_DCA           = CItemData::DCA,
+  FT_SHIFTDCA      = CItemData::SHIFTDCA,
   FT_EMAIL         = CItemData::EMAIL,
   FT_PROTECTED     = CItemData::PROTECTED,
   FT_SYMBOLS       = CItemData::SYMBOLS,
+  FT_POLICYNAME    = CItemData::POLICYNAME,
+  FT_KBSHORTCUT    = CItemData::KBSHORTCUT,
   FT_END           = CItemData::END,
 
   // Internal fields purely for filters
@@ -65,6 +68,7 @@ enum FieldType {
   FT_ENTRYTYPE     = CItemData::ENTRYTYPE,     // 0x101,
   FT_ENTRYSTATUS   = CItemData::ENTRYSTATUS,   // 0x102,
   FT_UNKNOWNFIELDS = CItemData::UNKNOWNFIELDS, // 0x103,
+  FT_PASSWORDLEN   = CItemData::PASSWORDLEN,   // 0x104
 
   // Password History Test fields
   HT_PRESENT       = 0x200,
@@ -120,7 +124,7 @@ struct st_FilterRow {
   // if filter type is a string
   StringX fstring;
   bool fcase; // case sensitive?
-  // if filter type is Double-Click Action
+  // if filter type is Double-Click Action or Shift-Double-Click Action
   short fdca;
   // if filter type is a entrytype
   CItemData::EntryType etype;
@@ -177,6 +181,35 @@ struct st_FilterRow {
     return *this;
   }
 
+
+  bool operator==(const st_FilterRow &that) const
+  {
+    if (this != &that) {
+      if (bFilterActive != that.bFilterActive ||
+          bFilterComplete != that.bFilterComplete ||
+          ftype != that.ftype ||
+          mtype != that.mtype ||
+          rule != that.rule ||
+          fnum1 != that.fnum1 ||
+          fnum2 != that.fnum2 ||
+          fdate1 != that.fdate1 ||
+          fdate2 != that.fdate2 ||
+          fdatetype != that.fdatetype ||
+          fstring != that.fstring ||
+          fcase != that.fcase ||
+          fdca != that.fdca ||
+          etype != that.etype ||
+          estatus != that.estatus ||
+          funit != that.funit ||
+          ltype != that.ltype)
+      return false;
+    }
+    return true;
+  }
+
+  bool operator!=(const st_FilterRow &that) const
+  {return !(*this == that);}
+
   void Empty()
   {
     bFilterActive = true;
@@ -247,6 +280,24 @@ struct st_filters {
     return *this;
   }
 
+  bool operator==(const st_filters &that) const
+  {
+    if (this != &that) {
+      if (fname != that.fname ||
+          num_Mactive != that.num_Mactive ||
+          num_Hactive != that.num_Hactive ||
+          num_Pactive != that.num_Pactive ||
+          vMfldata != that.vMfldata ||
+          vHfldata != that.vHfldata ||
+          vPfldata != that.vPfldata)
+      return false;
+    }
+    return true;
+  }
+
+  bool operator!=(const st_filters &that) const
+  {return !(*this == that);}
+
   void Empty()
   {
     fname = _T("");
