@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2012 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2015 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -13,8 +13,8 @@
 
 /*
 * A class to abstract away the persistent storage mechanism used to store and
-* retrieve user preferences. Pre-2.03 implementations used the Windows 
-* registry. People have asked for preferences to be stored along with the 
+* retrieve user preferences. Pre-2.03 implementations used the Windows
+* registry. People have asked for preferences to be stored along with the
 * database, so that the same preferences can be shared across computers
 * (e.g., using disk-on-key).
 *
@@ -44,6 +44,25 @@ struct st_prefShortcut {
   unsigned char cModifier;
 };
 
+// Bool preferences unknown to this version
+struct st_BP {
+  int index;
+  bool bValue;
+};
+
+// Integer preferences unknown to this version
+struct st_IP {
+  int index;
+  int iValue;
+};
+
+// String preferences unknown to this version
+struct st_SP {
+  int index;
+  TCHAR delim;
+  StringX sValue;
+};
+
 class CXMLprefs;
 struct PWPolicy;
 
@@ -54,7 +73,7 @@ public:
                      CF_FILE_RO, CF_FILE_RW, CF_FILE_RW_NEW};
 
   static const stringT cfgFileName; // one place for the config filename
-  
+
   static PWSprefs *GetInstance(); // singleton
   static void DeleteInstance();
   static bool SetConfigFile(const stringT &fn);
@@ -81,13 +100,13 @@ public:
     DontAskMinimizeClearYesNo, // Obsoleted in 3.13 - replaced by 2 separate
     DatabaseClear,
     DontAskSaveMinimize, // Obsoleted in 3.02
-    QuerySetDef, UseNewToolbar, UseSystemTray, 
-    LockOnWindowLock, 
+    QuerySetDef, UseNewToolbar, UseSystemTray,
+    LockOnWindowLock,
     LockOnIdleTimeout, // Obsoleted in 3.19 - replaced by Database equivalent
     EscExits, IsUTF8, HotKeyEnabled, MRUOnFileMenu,
     DisplayExpandedAddEditDlg, // Obsoleted in 3.18
     MaintainDateTimeStamps,
-    SavePasswordHistory, 
+    SavePasswordHistory,
     FindWraps, // Obsoleted in 3.11
     ShowNotesDefault,
     BackupBeforeEverySave, PreExpiryWarn,
@@ -101,6 +120,8 @@ public:
     HighlightChanges, HideSystemTray,
     UsePrimarySelectionForClipboard,  //Only under X-Windows
     CopyPasswordWhenBrowseToURL,
+    UseAltAutoType,  //Only under X-Windows
+    IgnoreHelpLoadError, //Only under WX
     NumBoolPrefs};
 
   enum IntPrefs {Column1Width, Column2Width, Column3Width, Column4Width,
@@ -109,7 +130,8 @@ public:
     NumPWHistoryDefault, BackupSuffix, BackupMaxIncremented,
     PreExpiryWarnDays, ClosedTrayIconColour, PWDigitMinLength,
     PWLowercaseMinLength, PWSymbolMinLength, PWUppercaseMinLength,
-    OptShortcutColumnWidth, ShiftDoubleClickAction,
+    OptShortcutColumnWidth, ShiftDoubleClickAction, DefaultAutotypeDelay,
+    DlgOrientation,
     NumIntPrefs};
 
   enum StringPrefs {CurrentBackup, CurrentFile, LastView, DefaultUsername,
@@ -124,7 +146,7 @@ public:
   // NOTE: When adding items, update the pwsafe.xsd & pwsafe_filter.xsd schemas
   //       to increase the maximum value in "dcaType"
   enum {minDCA = 0, DoubleClickCopyPassword = 0, DoubleClickViewEdit = 1,
-    DoubleClickAutoType = 2, DoubleClickBrowse = 3, 
+    DoubleClickAutoType = 2, DoubleClickBrowse = 3,
     DoubleClickCopyNotes = 4, DoubleClickCopyUsername = 5,
     DoubleClickCopyPasswordMinimize = 6,
     DoubleClickBrowsePlus = 7, DoubleClickRun = 8,
@@ -146,6 +168,9 @@ public:
   // Preferences changed (Database or Application or Shortcuts)
   enum {DB_PREF = 0, APP_PREF = 1, SHC_PREF = 2};
 
+  // Dialog orientation: Determine automatically or let the system decide
+  enum  {AUTO = 0, TALL = 1, WIDE = 2};
+
   // Preference types - values are powers of 2, except ptAll = sum of previous values
   enum PrefType {ptObsolete = 0, ptDatabase = 1, ptApplication = 2, ptAll = 3};
 
@@ -222,6 +247,8 @@ public:
   static void UnlockCFGFile(const stringT &filename);
   static bool IsLockedCFGFile(const stringT &filename);
 
+  void ClearUnknownPrefs(); // Clear unknown preferences vectors
+
 private:
   PWSprefs();
   ~PWSprefs();
@@ -279,5 +306,10 @@ private:
 
   stringT *m_MRUitems;
   std::vector<st_prefShortcut> m_vShortcuts;
+
+  // Preferences we don't know in this version of PWS
+  std::vector<st_BP> m_vUnknownBPrefs;
+  std::vector<st_IP> m_vUnknownIPrefs;
+  std::vector<st_SP> m_vUnknownSPrefs;
 };
 #endif /*  __PWSPREFS_H */
