@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2013 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2015 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -1441,12 +1441,12 @@ BOOL CCPListCtrl::PreTranslateMessage(MSG *pMsg)
   return CListCtrl::PreTranslateMessage(pMsg);
 } 
 
-bool CCPListCtrl::IsSelected(const int iRow)
+bool CCPListCtrl::IsSelected(DWORD_PTR iRow)
 {
   POSITION pos = GetFirstSelectedItemPosition();
 
   while (pos) {
-    if (GetNextSelectedItem(pos) == iRow)
+    if (GetNextSelectedItem(pos) == (int)iRow)
       return true;
   }
 
