@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2014 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2015 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -146,7 +146,8 @@ void DboxMain::SetUpInitialMenuStrings()
   // Add user Excluded Menu Items - anything that is a Popup Menu
     ID_FILEMENU, ID_EXPORTMENU, ID_IMPORTMENU, ID_EDITMENU,
     ID_VIEWMENU, ID_FILTERMENU, ID_CHANGEFONTMENU, ID_REPORTSMENU,
-    ID_MANAGEMENU, ID_LANGUAGEMENU, ID_HELPMENU, ID_FINDMENU, ID_EXPORTENTMENU,
+    ID_MANAGEMENU, ID_LANGUAGEMENU, ID_HELPMENU, ID_FINDMENU,
+    ID_EXPORTENTMENU, ID_EXPORTGROUPMENU,
 
   // Plus Exit (2 shortcuts Ctrl+Q and Alt+F4) and Help (F1)
     ID_MENUITEM_EXIT, ID_HELP,
@@ -255,6 +256,9 @@ void DboxMain::SetUpInitialMenuStrings()
   // Do Export Entry submenu
   //  InsertShortcuts(pSubMenu, m_MapMenuShortcuts, ID_EXPORTENTMENU);
 
+  // Do Export Group submenu
+  //  InsertShortcuts(pSubMenu, m_MapMenuShortcuts, ID_EXPORTGROUPMENU);
+
   // Do View Menu
   InsertShortcuts(pMainMenu, m_MapMenuShortcuts, ID_VIEWMENU);
 
@@ -300,7 +304,7 @@ void DboxMain::SetUpInitialMenuStrings()
 
   // Now that we have all menu strings - go get current accelerator strings
   // and update Map
-  MapMenuShortcutsIter iter, iter_entry, iter_group, inuse_iter;
+  MapMenuShortcutsIter iter, iter_entry, inuse_iter;
   HACCEL curacctbl = app.m_ghAccelTable;
   //if (curacctbl != NULL) {
   //  DestroyAcceleratorTable(app.m_ghAccelTable);
@@ -517,12 +521,12 @@ void DboxMain::CustomiseMenu(CMenu *pPopupMenu, const UINT uiMenuID,
   if (bDoShortcuts)
     SetUpMenuStrings(pPopupMenu);
 
-	// Change the 'Change Mode' text as appropriate	 
-  if (uiMenuID == ID_FILEMENU) {	 
-    pPopupMenu->ModifyMenu(ID_MENUITEM_CHANGEMODE, MF_BYCOMMAND,	 
-                           ID_MENUITEM_CHANGEMODE,	 
-                           bReadOnly ? CS_READWRITE : CS_READONLY);	 
-    return;	 
+  // Change the 'Change Mode' text as appropriate
+  if (uiMenuID == ID_FILEMENU) {
+    pPopupMenu->ModifyMenu(ID_MENUITEM_CHANGEMODE, MF_BYCOMMAND,
+                           ID_MENUITEM_CHANGEMODE,
+                           bReadOnly ? CS_READWRITE : CS_READONLY);
+    return;
   }
 
   // We have done for all except the Edit and View menus
@@ -654,13 +658,25 @@ void DboxMain::CustomiseMenu(CMenu *pPopupMenu, const UINT uiMenuID,
     }
 
     // Scenario 2 - Group selected (Tree view only)
-    //   Add Entry, Sep, <Group Items>, Sep, Clear Clipboard
+    //   Add Entry, Find, Sep, <Group Items>, Sep, Clear Clipboard
     if (!m_IsListView && bGroupSelected) {
       if (!bReadOnly) {
         pPopupMenu->AppendMenu(MF_ENABLED | MF_STRING,
                                ID_MENUITEM_ADD, tc_dummy);
-        pPopupMenu->InsertMenu((UINT)-1, MF_SEPARATOR);
       }
+
+      // Only have Find Next/Previous if find still active and entries were found
+      if (m_FindToolBar.IsVisible() && m_FindToolBar.EntriesFound()) {
+        pPopupMenu->AppendMenu(MF_ENABLED | MF_STRING,
+                               ID_MENUITEM_FIND, tc_dummy);
+        pPopupMenu->AppendMenu(MF_ENABLED | MF_STRING,
+                               ID_MENUITEM_FINDUP, tc_dummy);
+      } else { // otherwise just add "Find..."
+        pPopupMenu->AppendMenu(MF_ENABLED | MF_STRING,
+                               ID_MENUITEM_FINDELLIPSIS, tc_dummy);
+      }
+
+      pPopupMenu->InsertMenu((UINT)-1, MF_SEPARATOR);
       pPopupMenu->AppendMenu(MF_ENABLED | MF_STRING,
                              ID_MENUITEM_GROUPENTER, tc_dummy);
       if (!bReadOnly) {
@@ -683,6 +699,23 @@ void DboxMain::CustomiseMenu(CMenu *pPopupMenu, const UINT uiMenuID,
                                    ID_MENUITEM_UNPROTECTGROUP, tc_dummy);
         }
       }
+
+      CMenu GGsubMenu;
+      CString GGstr;
+      GGsubMenu.CreatePopupMenu();
+      // Re-use entry menu texts
+      GGstr.LoadString(IDS_EXPORTENT2PLAINTEXT);
+      GGsubMenu.AppendMenu(MF_ENABLED | MF_STRING,
+                           ID_MENUITEM_EXPORTGRP2PLAINTEXT, GGstr);
+      GGstr.LoadString(IDS_EXPORTENT2XML);
+      GGsubMenu.AppendMenu(MF_ENABLED | MF_STRING,
+                           ID_MENUITEM_EXPORTGRP2XML, GGstr);
+      GGstr.LoadString(IDS_EXPORTENT2DB);
+      GGsubMenu.AppendMenu(MF_ENABLED | MF_STRING,
+                           ID_MENUITEM_EXPORTGRP2DB, GGstr);
+      GGstr.LoadString(IDS_EXPORTGRPMENU);
+      pPopupMenu->AppendMenu(MF_POPUP, (UINT)GGsubMenu.Detach(), GGstr);
+
       pPopupMenu->InsertMenu((UINT)-1, MF_SEPARATOR);
       if (m_core.AnyToUndo() || m_core.AnyToRedo()) {
         pPopupMenu->AppendMenu(MF_ENABLED | MF_STRING,
@@ -856,6 +889,9 @@ void DboxMain::CustomiseMenu(CMenu *pPopupMenu, const UINT uiMenuID,
       EEstr.LoadString(IDS_EXPORTENT2XML);
       EEsubMenu.AppendMenu(MF_ENABLED | MF_STRING,
                           ID_MENUITEM_EXPORTENT2XML, EEstr);
+      EEstr.LoadString(IDS_EXPORTENT2DB);
+      EEsubMenu.AppendMenu(MF_ENABLED | MF_STRING,
+                           ID_MENUITEM_EXPORTENT2DB, EEstr);
       EEstr.LoadString(IDS_EXPORTENTMENU);
       pPopupMenu->AppendMenu(MF_POPUP, (UINT)EEsubMenu.Detach(), EEstr);
 
@@ -914,6 +950,7 @@ void DboxMain::OnInitMenuPopup(CMenu* pPopupMenu, UINT, BOOL)
     case ID_VIEWMENU:
     case ID_FILTERMENU:
     case ID_EXPORTENTMENU:
+    case ID_EXPORTGROUPMENU:
     case ID_CHANGEFONTMENU:
     case ID_REPORTSMENU:
     case ID_MANAGEMENU:
@@ -938,7 +975,7 @@ void DboxMain::OnInitMenuPopup(CMenu* pPopupMenu, UINT, BOOL)
     int iLangPos = app.FindMenuItem(pPopupMenu, ID_LANGUAGEMENU);
     if (iLangPos >= 0) {
       CMenu *pSubMenu = pPopupMenu->GetSubMenu(iLangPos);
-      const bool brc = ProcessLanguageMenu(pSubMenu);
+      brc = ProcessLanguageMenu(pSubMenu);
       pPopupMenu->EnableMenuItem(iLangPos, MF_BYPOSITION | (brc ? MF_ENABLED : MF_GRAYED));
     }
   }
