@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2014 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2015 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -19,11 +19,7 @@
 
 #include "core/sha256.h"
 
-#if defined(UNICODE)
 #define CLIPBOARD_TEXT_FORMAT CF_UNICODETEXT
-#else
-#define CLIPBOARD_TEXT_FORMAT CF_TEXT
-#endif
 
 #include "core/StringX.h"
 
