@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2011 Rony Shapiro <ronys@users.sourceforge.net>.
+* Copyright (c) 2003-2015 Rony Shapiro <ronys@users.sourceforge.net>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -10,7 +10,6 @@
 //
 
 #include "../stdafx.h"
-#include "../ThisMfcApp.h" // for online help
 #include "../GeneralMsgBox.h"
 #include "../DboxMain.h"
 #include "../PWResizeDialog.h"
@@ -44,8 +43,6 @@ CManageFiltersDlg::CManageFiltersDlg(CWnd* pParent,
   m_pCheckImageList(NULL), m_pImageList(NULL),
   m_iSortColumn(-1), m_bSortAscending(-1)
 {
-  m_pDbx = static_cast<DboxMain *>(pParent);
-
   PWSFilters::iterator mf_iter;
 
   for (mf_iter = m_MapFilters.begin();
@@ -347,7 +344,7 @@ void CManageFiltersDlg::OnFilterNew()
   flt_key.fpool = FPOOL_SESSION;
 
 do_edit:
-  bCreated = m_pDbx->EditFilter(&filters, false);
+  bCreated = GetMainDlg()->EditFilter(&filters, false);
 
   flt_key.cs_filtername = filters.fname;
 
@@ -378,9 +375,9 @@ do_edit:
     m_MapFilters.insert(PWSFilters::Pair(flt_key, filters));
 
     // Update DboxMain
-    m_pDbx->SetFilter(FPOOL_SESSION, filters.fname.c_str());
+    GetMainDlg()->SetFilter(FPOOL_SESSION, filters.fname.c_str());
     if (bJustDoIt)
-      m_pDbx->ApplyFilter(true);
+      GetMainDlg()->ApplyFilter(true);
 
     m_selectedfiltername = flt_key.cs_filtername.c_str();
     m_selectedfilterpool = flt_key.fpool;
@@ -408,7 +405,7 @@ void CManageFiltersDlg::OnFilterEdit()
   st_filters filters = mf_iter->second;
 
 do_edit:
-  bChanged = m_pDbx->EditFilter(&filters, false);
+  bChanged = GetMainDlg()->EditFilter(&filters, false);
   if (bChanged) {
     // Has user changed the filter's name?
     // If so, check for conflict.
@@ -453,9 +450,9 @@ do_edit:
     m_selectedfiltername = flt_key.cs_filtername.c_str();
 
     // Update DboxMain's current filter
-    m_pDbx->SetFilter(flt_key.fpool, filters.fname.c_str());
+    GetMainDlg()->SetFilter(flt_key.fpool, filters.fname.c_str());
     if (bJustDoIt)
-      m_pDbx->ApplyFilter(true);
+      GetMainDlg()->ApplyFilter(true);
 
     UpdateFilterList();
     DisplayFilterProperties(&filters);
@@ -507,8 +504,8 @@ void CManageFiltersDlg::OnFilterCopy()
   }
   if (bCopied) {
     m_bDBFiltersChanged = true;
-    m_pDbx->SetChanged(DboxMain::Data);
-    m_pDbx->ChangeOkUpdate();
+    GetMainDlg()->SetChanged(DboxMain::Data);
+    GetMainDlg()->ChangeOkUpdate();
   }
 
   UpdateFilterList();
@@ -543,8 +540,8 @@ void CManageFiltersDlg::OnFilterDelete()
   m_MapFilters.erase(flt_key);
   if (m_selectedfilterpool == FPOOL_DATABASE) {
     m_bDBFiltersChanged = true;
-    m_pDbx->SetChanged(DboxMain::Data);
-    m_pDbx->ChangeOkUpdate();
+    GetMainDlg()->SetChanged(DboxMain::Data);
+    GetMainDlg()->ChangeOkUpdate();
   }
 
   st_FilterItemData *pflt_idata = (st_FilterItemData *)m_FilterLC.GetItemData(m_selectedfilter);
@@ -560,7 +557,7 @@ void CManageFiltersDlg::OnFilterDelete()
     m_activefilter = -1;
     m_activefilterpool = FPOOL_LAST;
     m_activefiltername = L"";
-    m_pDbx->ClearFilter();
+    GetMainDlg()->ClearFilter();
   }
 
   m_selectedfilter = -1;
@@ -578,7 +575,7 @@ void CManageFiltersDlg::OnFilterDelete()
 
 void CManageFiltersDlg::OnFilterImport()
 {
-  m_pDbx->ImportFilters();
+  GetMainDlg()->ImportFilters();
 
   UpdateFilterList();
 }
@@ -601,15 +598,15 @@ void CManageFiltersDlg::OnFilterExport()
     Filters.insert(PWSFilters::Pair(pflt_idata->flt_key, mf_iter->second));
   }
   if (!Filters.empty()) {
-    m_pDbx->ExportFilters(Filters);
+    GetMainDlg()->ExportFilters(Filters);
     Filters.clear();
   }
 }
 
 void CManageFiltersDlg::SetFilter()
 {
-  m_pDbx->SetFilter(m_selectedfilterpool, m_selectedfiltername);
-  if (!m_pDbx->ApplyFilter(true))
+  GetMainDlg()->SetFilter(m_selectedfilterpool, m_selectedfiltername);
+  if (!GetMainDlg()->ApplyFilter(true))
     return;
 
   m_activefilterpool = m_selectedfilterpool;
@@ -633,7 +630,7 @@ void CManageFiltersDlg::SetFilter()
 
 void CManageFiltersDlg::ClearFilter()
 {
-  m_pDbx->ClearFilter();
+  GetMainDlg()->ClearFilter();
 
   m_activefilterpool = FPOOL_LAST;
   m_activefiltername = L"";
@@ -758,12 +755,12 @@ void CManageFiltersDlg::DisplayFilterProperties(st_filters *pfilters)
 
   bool bSave = m_FPROPHeader.GetStopChangeFlag();
   m_FPROPHeader.SetStopChangeFlag(false);
-  for (int i = 0; i < MFPRP_CRITERIA_TEXT; i++) {
-    m_FilterProperties.SetColumnWidth(i, LVSCW_AUTOSIZE);
-    int iw1 =  m_FilterProperties.GetColumnWidth(i);
-    m_FilterProperties.SetColumnWidth(i, LVSCW_AUTOSIZE_USEHEADER);
-    int iw2 =  m_FilterProperties.GetColumnWidth(i);
-    m_FilterProperties.SetColumnWidth(i, max(iw1, iw2));
+  for (int j = 0; j < MFPRP_CRITERIA_TEXT; j++) {
+    m_FilterProperties.SetColumnWidth(j, LVSCW_AUTOSIZE);
+    int iw1 =  m_FilterProperties.GetColumnWidth(j);
+    m_FilterProperties.SetColumnWidth(j, LVSCW_AUTOSIZE_USEHEADER);
+    int iw2 =  m_FilterProperties.GetColumnWidth(j);
+    m_FilterProperties.SetColumnWidth(j, max(iw1, iw2));
   }
   m_FilterProperties.SetColumnWidth(MFPRP_CRITERIA_TEXT, LVSCW_AUTOSIZE_USEHEADER);
   m_FilterProperties.SetRedraw(TRUE);
@@ -1074,28 +1071,32 @@ CString CManageFiltersDlg::GetFieldTypeName(FieldType ft)
 {
   int nID = IDSC_UNKNOWN;
   switch (ft) {
-  case FT_GROUP:      return CItemData::FieldName(CItemData::GROUP).c_str();
-  case FT_TITLE:      return CItemData::FieldName(CItemData::TITLE).c_str();
-  case FT_GROUPTITLE: return CItemData::FieldName(CItemData::GROUPTITLE).c_str();
-  case FT_USER:       return CItemData::FieldName(CItemData::USER).c_str();
-  case FT_PASSWORD:   return CItemData::FieldName(CItemData::PASSWORD).c_str();
-  case FT_NOTES:      return CItemData::FieldName(CItemData::NOTES).c_str();
-  case FT_AUTOTYPE:   return CItemData::FieldName(CItemData::AUTOTYPE).c_str();
-  case FT_URL:        return CItemData::FieldName(CItemData::URL).c_str();
-  case FT_RUNCMD:     return CItemData::FieldName(CItemData::RUNCMD).c_str();
-  case FT_DCA:        return CItemData::FieldName(CItemData::DCA).c_str();
-  case FT_EMAIL:      return CItemData::FieldName(CItemData::EMAIL).c_str();
-  case FT_PROTECTED:  return CItemData::FieldName(CItemData::PROTECTED).c_str();
-  case FT_SYMBOLS:    return CItemData::FieldName(CItemData::SYMBOLS).c_str();
-  case FT_CTIME:      return CItemData::FieldName(CItemData::CTIME).c_str();
-  case FT_ATIME:      return CItemData::FieldName(CItemData::ATIME).c_str();
-  case FT_PMTIME:     return CItemData::FieldName(CItemData::PMTIME).c_str();
-  case FT_XTIME:      return CItemData::FieldName(CItemData::XTIME).c_str();
-  case FT_XTIME_INT:  return CItemData::FieldName(CItemData::XTIME_INT).c_str();
-  case FT_RMTIME:     return CItemData::FieldName(CItemData::RMTIME).c_str();
-  case FT_PWHIST:     return CItemData::FieldName(CItemData::PWHIST).c_str();
-  case FT_POLICY:     return CItemData::FieldName(CItemData::POLICY).c_str();
-  
+  case FT_GROUP:        return CItemData::FieldName(CItemData::GROUP).c_str();
+  case FT_TITLE:        return CItemData::FieldName(CItemData::TITLE).c_str();
+  case FT_GROUPTITLE:   return CItemData::FieldName(CItemData::GROUPTITLE).c_str();
+  case FT_USER:         return CItemData::FieldName(CItemData::USER).c_str();
+  case FT_PASSWORD:     return CItemData::FieldName(CItemData::PASSWORD).c_str();
+  case FT_NOTES:        return CItemData::FieldName(CItemData::NOTES).c_str();
+  case FT_AUTOTYPE:     return CItemData::FieldName(CItemData::AUTOTYPE).c_str();
+  case FT_URL:          return CItemData::FieldName(CItemData::URL).c_str();
+  case FT_RUNCMD:       return CItemData::FieldName(CItemData::RUNCMD).c_str();
+  case FT_DCA:          return CItemData::FieldName(CItemData::DCA).c_str();
+  case FT_SHIFTDCA:     return CItemData::FieldName(CItemData::SHIFTDCA).c_str();
+  case FT_EMAIL:        return CItemData::FieldName(CItemData::EMAIL).c_str();
+  case FT_PROTECTED:    return CItemData::FieldName(CItemData::PROTECTED).c_str();
+  case FT_SYMBOLS:      return CItemData::FieldName(CItemData::SYMBOLS).c_str();
+  case FT_CTIME:        return CItemData::FieldName(CItemData::CTIME).c_str();
+  case FT_ATIME:        return CItemData::FieldName(CItemData::ATIME).c_str();
+  case FT_PMTIME:       return CItemData::FieldName(CItemData::PMTIME).c_str();
+  case FT_XTIME:        return CItemData::FieldName(CItemData::XTIME).c_str();
+  case FT_XTIME_INT:    return CItemData::FieldName(CItemData::XTIME_INT).c_str();
+  case FT_RMTIME:       return CItemData::FieldName(CItemData::RMTIME).c_str();
+  case FT_PWHIST:       return CItemData::FieldName(CItemData::PWHIST).c_str();
+  case FT_POLICY:       return CItemData::FieldName(CItemData::POLICY).c_str();
+  case FT_POLICYNAME:   return CItemData::FieldName(CItemData::POLICYNAME).c_str();
+  case FT_KBSHORTCUT:   return CItemData::FieldName(CItemData::KBSHORTCUT).c_str();
+
+  case FT_PASSWORDLEN:   nID = IDS_PASSWORDLEN; break;
   case FT_ENTRYSIZE:     nID = IDS_ENTRYSIZE; break;
   case FT_ENTRYTYPE:     nID = IDS_ENTRYTYPE; break;
   case FT_ENTRYSTATUS:   nID = IDS_ENTRYSTATUS; break;
@@ -1107,14 +1108,14 @@ CString CManageFiltersDlg::GetFieldTypeName(FieldType ft)
   case HT_CHANGEDATE:    nID = IDS_HDATE; break;
   case HT_PASSWORDS:     nID = HT_PASSWORDS; break;
   case PT_PRESENT:       nID = IDS_PRESENT; break;
-  case PT_LENGTH:        nID = IDS_PLENGTH; break;
+  case PT_LENGTH:        nID = IDSC_PLENGTH; break;
   case PT_LOWERCASE:     nID = IDS_PLOWER; break;
   case PT_UPPERCASE:     nID = IDS_PUPPER; break;
   case PT_DIGITS:        nID = IDS_PDIGITS; break;
   case PT_SYMBOLS:       nID = IDS_PSYMBOL; break;
-  case PT_HEXADECIMAL:   nID = IDS_PHEXADECIMAL; break;
-  case PT_EASYVISION:    nID = IDS_PEASYVISION; break;
-  case PT_PRONOUNCEABLE: nID = IDS_PPRONOUNCEABLE; break;
+  case PT_HEXADECIMAL:   nID = IDSC_PHEXADECIMAL; break;
+  case PT_EASYVISION:    nID = IDSC_PEASYVISION; break;
+  case PT_PRONOUNCEABLE: nID = IDSC_PPRONOUNCEABLE; break;
     default:
       ASSERT(0);
   }
@@ -1167,7 +1168,7 @@ int CALLBACK CManageFiltersDlg::FLTCompareFunc(LPARAM lParam1,
   st_FilterItemData *pRHS = (st_FilterItemData *)lParam2;
   int i1, i2;
 
-  int iResult;
+  int iResult(0);
   switch(nSortColumn) {
     case MFLC_FILTER_NAME:
       iResult = pLHS->flt_key.cs_filtername.compare(pRHS->flt_key.cs_filtername);
@@ -1178,9 +1179,7 @@ int CALLBACK CManageFiltersDlg::FLTCompareFunc(LPARAM lParam1,
     case MFLC_INUSE:
       i1 = (int)(pLHS->flt_flags & MFLT_INUSE);
       i2 = (int)(pRHS->flt_flags & MFLT_INUSE);
-      if (i1 == i2)
-        iResult = 0;
-      else
+      if (i1 != i2)
         iResult = (i1 < i2) ? -1 : 1;
       break;
     case MFLC_COPYTODATABASE:
@@ -1193,24 +1192,19 @@ int CALLBACK CManageFiltersDlg::FLTCompareFunc(LPARAM lParam1,
         i1 = ((pLHS->flt_flags & MFLT_REQUEST_COPY_TO_DB) == MFLT_REQUEST_COPY_TO_DB) ? 2 : 1;
       if (pRHS->flt_key.fpool != FPOOL_DATABASE)
         i2 = ((pRHS->flt_flags & MFLT_REQUEST_COPY_TO_DB) == MFLT_REQUEST_COPY_TO_DB) ? 2 : 1;
-      if (i1 == i2)
-        iResult = 0;
-      else
+      if (i1 != i2)
         iResult = (i1 < i2) ? -1 : 1;
       break;
     case MFLC_EXPORT:
       i1 = (int)(pLHS->flt_flags & MFLT_REQUEST_EXPORT);
       i2 = (int)(pRHS->flt_flags & MFLT_REQUEST_EXPORT);
-      if (i1 == i2)
-        iResult = 0;
-      else
+      if (i1 != i2)
         iResult = (i1 < i2) ? -1 : 1;
       break;
     default:
-      iResult = 0; // should never happen - just keep compiler happy
       ASSERT(FALSE);
   }
-  if (!self->m_bSortAscending) {
+  if (!self->m_bSortAscending && iResult != 0) {
     iResult *= -1;
   }
   return iResult;
@@ -1218,7 +1212,7 @@ int CALLBACK CManageFiltersDlg::FLTCompareFunc(LPARAM lParam1,
 
 void CManageFiltersDlg::OnColumnClick(NMHDR *pNotifyStruct, LRESULT *pLResult) 
 {
-  NM_LISTVIEW* pNMLV = reinterpret_cast<NM_LISTVIEW *>(pNotifyStruct);
+  NMLISTVIEW *pNMLV = reinterpret_cast<NMLISTVIEW *>(pNotifyStruct);
 
   // Get column index to CItemData value
   int iIndex = pNMLV->iSubItem;
@@ -1278,8 +1272,6 @@ BOOL CManageFiltersDlg::PreTranslateMessage(MSG* pMsg)
 
 void CManageFiltersDlg::OnHelp()
 {
-  CString cs_HelpTopic;
-  cs_HelpTopic = app.GetHelpFileName() + L"::/html/filters.html#ManagingFilters";
-  HtmlHelp(DWORD_PTR((LPCWSTR)cs_HelpTopic), HH_DISPLAY_TOPIC);
+  ShowHelp(L"::/html/filters.html#ManagingFilters");
 }
 
