@@ -5,7 +5,7 @@
 // Modified by:
 // Created:     Wed 14 Jan 2009 10:11:39 PM IST
 // RCS-ID:
-// Copyright:   Copyright (c) 2003-2014 Rony Shapiro <ronys@users.sourceforge.net>
+// Copyright:   Copyright (c) 2003-2015 Rony Shapiro <ronys@users.sourceforge.net>
 // Licence:
 /////////////////////////////////////////////////////////////////////////////
 
@@ -83,6 +83,7 @@ public:
 
   void OnIdleTimer(wxTimerEvent& timerEvent);
   void ConfigureIdleTimer();
+  void RestartIdleTimer();
   void OnHelp(wxCommandEvent& evt);
   void OnDBGUIPrefsChange(wxEvent& evt);
 
@@ -97,7 +98,6 @@ public:
  private:
     PWScore m_core;
     wxTimer* m_idleTimer;
-    bool m_idleFlag; // true unless an event happened in the idle lock interval;
     PasswordSafeFrame* m_frame;
     enum { IDLE_TIMER_ID = 33 } ;
     CRecentDBList *m_recentDatabases;
@@ -105,17 +105,17 @@ public:
     //A map of dialog titles (or tab names) vs help sections
     WX_DECLARE_STRING_HASH_MAP( wxString, StringToStringMap );
     StringToStringMap& GetHelpMap();
-    wxHtmlHelpController* m_controller;
-
+    wxHtmlHelpController* m_helpController;
     wxIconBundle m_appIcons;
     wxLocale *m_locale; // set in Init(), deleted in d'tor, unused elsewhere
-
+    bool ActivateHelp(wxLanguage language);
  public:
     CRecentDBList &recentDatabases();
     uint32 GetHashIters() const {return m_core.GetHashIters();}
     void SetHashIters(uint32 value) {m_core.SetHashIters(value);}
-    bool ActivateLanguage(wxLanguage language);
+    bool ActivateLanguage(wxLanguage language, bool tryOnly);
     wxLanguage GetSystemLanguage();
+    wxLanguage GetSelectedLanguage();
 };
 
 /*!
